"""
This type stub file was generated by pyright.
"""

from ollama import Client as _OllamaClient
from fundar_llms.api.interface import Base64, BaseResponse, PlainPromptInterface, response_dataclass_options
from typing import Any, Optional
from dataclasses import dataclass

def dict_dif(a, b): # -> dict[Any, Any]:
    ...

@dataclass(**response_dataclass_options)
class OllamaResponse(BaseResponse):
    created_at: str
    prompt_eval_count: int
    prompt_eval_duration: int
    eval_count: int
    eval_duration: int
    ...


OLLAMA_DEFAULT_OPTIONS = ...
class OllamaClient(PlainPromptInterface, _OllamaClient):
    def list_models(self, max_vram=...): # -> list[Any]:
        ...
    
    def generate(self, model: str, prompt: str, raw: Optional[bool] = ..., image: Optional[Base64] = ..., suffix: Optional[str] = ..., format: Optional[str] = ..., system: Optional[str] = ..., context: Optional[Any] = ..., stream: Optional[bool] = ..., num_ctx: Optional[int] = ..., num_predict: Optional[int] = ..., temperature: Optional[float] = ..., top_k: Optional[int] = ..., top_p: Optional[float] = ..., *args, **kwargs) -> Any:
        ...
    





"""
This type stub file was generated by pyright.
"""

from dataclasses import dataclass
from typing import Optional

tokenizer_model_dataclass_options = ...
auto_tokenizer_ = ...
@dataclass(**tokenizer_model_dataclass_options)
class TokenizerModel:
    name: str
    needs_auth: bool = ...
    def __str__(self) -> str:
        ...
    
    def auto_tokenizer_from_pretrained(self):
        ...
    


DEFAULT_TOKENIZER_MAP = ...
def get_tokenizer(model_name: str, tokenizer_map: Optional[dict[str, TokenizerModel]] = ..., default: Optional[TokenizerModel] = ...) -> TokenizerModel:
    ...




"""
This type stub file was generated by pyright.
"""

_is_cuda_available_ = ...
def is_cuda_available() -> bool:
    ...

def available_vram_nvidia_smi(): # -> tuple[int, int]:
    ...

def available_vram_torch(): # -> tuple[int, Any]:
    ...

def get_available_vram(): # -> tuple[int, int] | tuple[int, Any]:
    ...




import sys
import importlib
from typing import TYPE_CHECKING
import warnings

if TYPE_CHECKING:
    try:
        sys.modules[__name__ + '.llms'] = importlib.import_module('fundar_llms')
    except ImportError:
        # raise ImportError("'fundar_llms' isn't installed. Get it from github.com/datos-Fundar/llms")
        warnings.warn("'fundar_llms' isn't installed. Get it from github.com/datos-Fundar/llms")


"""
This type stub file was generated by pyright.
"""

from abc import ABC as AbstractBaseClass
from typing import Any

class DataclassDictUtilsMixin(AbstractBaseClass):
    @classmethod
    def from_dict(cls, data: dict[str, Any]): # -> Self:
        ...
    
    def to_dict(self, exclude=..., compact=...) -> dict[str, Any]:
        ...
    





"""
This type stub file was generated by pyright.
"""

def umap_project_embeddings(umap_transform, embeddings, show_progress, strict: bool, dimensions: int): # -> NDArray[float64] | coo_matrix | Any | list[Any]:
    ...

def tsne_project_embeddings(tsne_transform, embeddings, show_progress):
    ...

def project_data(transform, embeddings, by: str = ..., show_progress: bool = ..., strict: bool = ..., dimensions: int = ...): # -> NDArray[float64] | coo_matrix | Any | list[Any]:
    ...




"""
This type stub file was generated by pyright.
"""

from typing import Optional
from collections.abc import Iterable

def subdict(d, keys): # -> dict[Any, Any]:
    ...

_reranker = ...
def upsert_reranker_model(model_name=..., device=..., **kwargs): # -> CrossEncoder:
    ...

_ALL_RERANK_ELEMENTS = ...
_INCLUDE_MAP = ...
def rerank(universe: Iterable[str], query: str, cross_encoder=..., include: Optional[Iterable[str]] = ..., *args, **kwargs): # -> list[tuple[str, ...]]:
    ...




"""
This type stub file was generated by pyright.
"""

import fundar_llms.api.interface
import fundar_llms.api.tokenizers
import fundar_llms.api.ollama
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    ...



"""
This type stub file was generated by pyright.
"""

import uuid
from typing import Any, Iterable, Optional, ParamSpec, TypeVar

P = ParamSpec('P')
T = TypeVar('T')
def consume(iterator: Iterable[Any], n: Optional[int] = ...) -> None:
    "Advance the iterator n-steps ahead. If n is none, consume entirely."
    ...

def pass_generator_as_copy(*xs: Iterable[str]): # -> Callable[..., Callable[P, T]]:
    ...

class UuidGenerator:
    def __init__(self, seed: Optional[int] = ...) -> None:
        ...
    
    def reset(self): # -> Self:
        ...
    
    def next(self, n: Optional[int] = ...): # -> UUID | Generator[UUID, None, None]:
        ...
    
    def __iter__(self): # -> Generator[UUID | Generator[UUID, None, None], Any, NoReturn]:
        ...
    
    @pass_generator_as_copy('xs')
    def map(self, xs: Iterable[T], offset: Optional[int] = ...) -> Iterable[uuid.UUID]:
        ...
    
    @pass_generator_as_copy('xs')
    def zipWith(self, xs: Iterable[T], offset: Optional[int] = ...) -> Iterable[tuple[uuid.UUID, T]]:
        ...
    





"""
This type stub file was generated by pyright.
"""

from langchain.document_loaders import PyPDFLoader
from langchain_text_splitters import RecursiveCharacterTextSplitter
from langchain_core.documents import Document
from collections.abc import Iterable
from typing import Optional, TypeVar
from fundar_llms.utils.common import allow_opaque_constructor

T = TypeVar('T')
DEFAULT_PDF_LOADER = PyPDFLoader
def load_document(filepath: str, loader=..., seed_id: Optional[int] = ...) -> list[Document]:
    ...

DEFAULT_RCT_SPLITTER = ...
@allow_opaque_constructor(splitter=RecursiveCharacterTextSplitter)
def split_document(xs, splitter=..., seed_id: Optional[int] = ...) -> list[Document]:
    ...

def load_and_split(filepath: str, loader=..., splitter=..., seed_id: Optional[int] = ..., flatten=...): # -> list[Document] | list[list[Document]]:
    ...

_sentence_transformer_obj = ...
def SentenceTransformer(*args, **kwargs): # -> SentenceTransformer:
    """
    Default args:
        - model: sentence-transformers/all-mpnet-base-v2
        - device: auto (cuda if available)
    """
    ...

def encode_with_multiprocessing(transformer, pool): # -> Callable[..., NDArray[Any]]:
    ...

@allow_opaque_constructor(sentence_transformer=SentenceTransformer)
def vectorize_document(x: str | Document | Iterable[Document | str], sentence_transformer=..., uid=..., additional_metadata=..., devices=...): # -> list[dict[str, List[Tensor] | ndarray[Any, Any] | Tensor | NDArray[Any] | Any]] | list[dict[str, Document | str | dict[Any, Any] | UUID | Tensor]]:
    ...




"""
This type stub file was generated by pyright.
"""

from typing import ParamSpec, Sequence, TypeVar

P = ParamSpec('P')
T = TypeVar('T')
def flatten(nested_list: Sequence[Sequence[T]], max_level=...) -> Sequence[T]:
    ...

def split_list_into_chunks(lst: list[T], chunk_size: int): # -> list[list[T]]:
    ...

def allow_opaque_constructor(**objects): # -> Callable[..., Callable[P, T]]:
    ...




"""
This type stub file was generated by pyright.
"""

from typing import Any, Optional, Protocol
from dataclasses import dataclass
from fundar_llms import Base64, Context
from fundar_llms.utils import DataclassDictUtilsMixin

response_dataclass_options = ...
@dataclass(**response_dataclass_options)
class BaseResponse(DataclassDictUtilsMixin):
    model: str
    prompt: str
    system: str
    response: str
    total_duration: int
    load_duration: Optional[int] = ...
    done: Optional[bool] = ...
    done_reason: Optional[str] = ...
    context: Optional[Context] = ...
    num_ctx: Optional[int] = ...
    num_predict: Optional[int] = ...
    temperature: Optional[float] = ...
    top_k: Optional[float] = ...
    top_p: Optional[float] = ...
    extra: Optional[Any] = ...


class PlainPromptInterface(Protocol):
    def generate(self, model: str, prompt: str, raw: Optional[bool] = ..., image: Optional[Base64] = ..., suffix: Optional[str] = ..., format: Optional[str] = ..., system: Optional[str] = ..., context: Optional[Context] = ..., stream: Optional[bool] = ..., num_ctx: Optional[int] = ..., num_predict: Optional[int] = ..., temperature: Optional[float] = ..., top_k: Optional[int] = ..., top_p: Optional[float] = ..., *args, **kwargs) -> BaseResponse:
        ...
    


